==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Visual/analyzer/translations/analyzer_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="36"/>
        <source>Qmmp Analyzer</source>
        <translation>Analyzer Qmmp</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="323"/>
        <source>Peaks</source>
        <translation>Puncak</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="326"/>
        <source>Refresh Rate</source>
        <translation>Segarkan Laju</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="329"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="330"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="331"/>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="332"/>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="339"/>
        <source>Analyzer Falloff</source>
        <translation>Analyzer Merosot</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="342"/>
        <location filename="../analyzer.cpp" line="356"/>
        <source>Slowest</source>
        <translation>Agak Lambat</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="343"/>
        <location filename="../analyzer.cpp" line="357"/>
        <source>Slow</source>
        <translation>Lambat</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="344"/>
        <location filename="../analyzer.cpp" line="358"/>
        <source>Medium</source>
        <translation>Sedang</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="345"/>
        <location filename="../analyzer.cpp" line="359"/>
        <source>Fast</source>
        <translation>Cepat</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="346"/>
        <location filename="../analyzer.cpp" line="360"/>
        <source>Fastest</source>
        <translation>Agak Cepat</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="353"/>
        <source>Peaks Falloff</source>
        <translation>Puncak Merosot</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="367"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Layar Penuh</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="367"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>ColorWidget</name>
    <message>
        <location filename="../colorwidget.cpp" line="37"/>
        <source>Select Color</source>
        <translation>Pilih Warna</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Analyzer Plugin Settings</source>
        <translation>Setelan Plugin Analyzer</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>General</source>
        <translation>Umum</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Cells size:</source>
        <translation>Ukuran sel:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="101"/>
        <source>Colors</source>
        <translation>Warna</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Peaks:</source>
        <translation>Puncak:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Analyzer #1:</source>
        <translation>Analyzer #1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="171"/>
        <source>Background:</source>
        <translation>Background:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="203"/>
        <source>Analyzer #2:</source>
        <translation>Analyzer #2:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="248"/>
        <source>Analyzer #3:</source>
        <translation>Analyzer #3:</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="30"/>
        <source>Analyzer Plugin</source>
        <translation>Plugin Analyzer</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="49"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>Tentang Plugin Visual Analyzer</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>Plugin Visual Analyzer Qmmp</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp-1.7.3.tar.bz2: qmmp-1.7.3/src/plugins/Visual/analyzer/translations/analyzer_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="36"/>
        <source>Qmmp Analyzer</source>
        <translation>Analyzer Qmmp</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="312"/>
        <source>Peaks</source>
        <translation>Puncak</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="315"/>
        <source>Refresh Rate</source>
        <translation>Segarkan Laju</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="318"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="319"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="320"/>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="321"/>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="328"/>
        <source>Analyzer Falloff</source>
        <translation>Analyzer Merosot</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="331"/>
        <location filename="../analyzer.cpp" line="345"/>
        <source>Slowest</source>
        <translation>Agak Lambat</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="332"/>
        <location filename="../analyzer.cpp" line="346"/>
        <source>Slow</source>
        <translation>Lambat</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="333"/>
        <location filename="../analyzer.cpp" line="347"/>
        <source>Medium</source>
        <translation>Sedang</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="334"/>
        <location filename="../analyzer.cpp" line="348"/>
        <source>Fast</source>
        <translation>Cepat</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="335"/>
        <location filename="../analyzer.cpp" line="349"/>
        <source>Fastest</source>
        <translation>Agak Cepat</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="342"/>
        <source>Peaks Falloff</source>
        <translation>Puncak Merosot</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="356"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Layar Penuh</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="356"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>AnalyzerColorWidget</name>
    <message>
        <location filename="../analyzercolorwidget.cpp" line="37"/>
        <source>Select Color</source>
        <translation type="unfinished">Pilih Warna</translation>
    </message>
</context>
<context>
    <name>AnalyzerSettingsDialog</name>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="14"/>
        <source>Analyzer Plugin Settings</source>
        <translation type="unfinished">Setelan Plugin Analyzer</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="35"/>
        <source>General</source>
        <translation type="unfinished">Umum</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="41"/>
        <source>Cells size:</source>
        <translation type="unfinished">Ukuran sel:</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="101"/>
        <source>Colors</source>
        <translation type="unfinished">Warna</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="107"/>
        <source>Peaks:</source>
        <translation type="unfinished">Puncak:</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="139"/>
        <source>Analyzer #1:</source>
        <translation type="unfinished">Analyzer #1:</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="171"/>
        <source>Background:</source>
        <translation type="unfinished">Background:</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="203"/>
        <source>Analyzer #2:</source>
        <translation type="unfinished">Analyzer #2:</translation>
    </message>
    <message>
        <location filename="../analyzersettingsdialog.ui" line="248"/>
        <source>Analyzer #3:</source>
        <translation type="unfinished">Analyzer #3:</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="30"/>
        <source>Analyzer Plugin</source>
        <translation>Plugin Analyzer</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="49"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>Tentang Plugin Visual Analyzer</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>Plugin Visual Analyzer Qmmp</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
